@@ -16,7 +16,7 @@ def gather_wits_for_period(asset_id, start, end, limit=1800):
     return wits_dataset
 
 
-def get_config_by__id(config_collection, _id):
+def get_config_by_id(config_collection, _id):
     from worker.data.api import API
 
     worker = API()
